# PyStrukts

[![Build](https://github.com/rubenperezm/pystrukts/actions/workflows/test.yml/badge.svg)](https://github.com/rubenperezm/pystrukts/actions/workflows/test.yml/badge.svg)
[![codecov](https://codecov.io/gh/rubenperezm/pystrukts/graph/badge.svg?token=OLV3EOPYFI)](https://codecov.io/gh/rubenperezm/pystrukts)
[![PyPI Version](https://img.shields.io/pypi/v/pystrukts.svg)](https://pypi.org/project/pystrukts)
<!-- [![Python Versions](https://img.shields.io/pypi/pyversions/pystrukts.svg)](https://pypi.org/project/pystrukts) -->


A Python library for data structures. This library provides more than 20 advanced data structures not available in the Python standard library, including:

- [x] Singly Linked List
- [x] Doubly Linked List
- [x] Circular Linked List (Single, Double)
- [ ] Generic Tree
- [ ] Binary Search Tree
- [ ] Ternary Search Tree
- [ ] Suffix Tree
- [ ] AVL Tree
- [ ] Red-Black Tree
- [ ] Splay Tree
- [ ] B-Tree
- [ ] B+ Tree
- [ ] R-Tree
- [ ] Interval Tree
- [ ] Segment Tree
- [ ] Fenwick Tree
- [x] Disjoint Set
- [ ] Skip List
- [x] Trie
- [x] Max Heap
- [x] Graph (Adjacency Matrix)
- [ ] Graph (Adjacency List)
